@@ -8,12 +8,16 @@ use strict;
 
 package CPAN::Site;
 use vars '$VERSION';
-$VERSION = '0.20';
+$VERSION = '0.21';
+
 use base 'CPAN';
 
-my $reload_orig;
+our $reload_orig;
+our $config_loader;
 BEGIN {
   $reload_orig = \&CPAN::Index::reload;
+  eval "require CPAN::HandleConfig";
+  $config_loader = $@ ? 'CPAN::Config' : 'CPAN::HandleConfig';
 }
 
 # Add "CPAN" to the list of exported items
@@ -25,7 +29,8 @@ sub import
    goto &$import;
 }
 
-CPAN::Config->load if CPAN::Config->can('load');
+$config_loader->load
+    if $config_loader->can('load');
 
 if(my $urls = $ENV{CPANSITE})
 {   unshift @{$CPAN::Config->{urllist}}, split ' ', $urls;
